@@ -48,7 +48,9 @@ class Array:
         if "t" not in array.dims:
             array = array.expand_dims("t")
         if "c" not in array.dims:
-            array = array.expand_dims("t")
+            array = array.expand_dims("c")
+        if "z" not in array.dims:
+            array = array.expand_dims("z")
 
         chunks = chunks or {
             "t": 1,
